@@ -1,5 +1,5 @@
 Factor <- function(x, name = deparse(expr), levelnames=levels(x),
-		   texify = TRUE, expr = substitute(x), override = TRUE) {
+		   texify = getOption("tables.texify", FALSE), expr = substitute(x), override = TRUE) {
     force(name)
     force(expr)
     x <- as.factor(x)
@@ -9,13 +9,13 @@ Factor <- function(x, name = deparse(expr), levelnames=levels(x),
     }
     force(levelnames)
     RowFactor(x, name = name, levelnames = levelnames, spacing=FALSE, 
-              texify = FALSE, expr = expr, override = override)
+              texify = texify, expr = expr, override = override)
 }
 
 Multicolumn <- function(x, name = deparse(expr),
                         levelnames = levels(x),
                         width = 2, first = 1, justify = "l", 
-                        texify = TRUE, expr = substitute(x), override = TRUE) {
+                        texify = getOption("tables.texify", FALSE), expr = substitute(x), override = TRUE) {
     force(name)
     force(expr)
     x <- as.factor(x)
@@ -29,7 +29,7 @@ Multicolumn <- function(x, name = deparse(expr),
 RowFactor <- function(x, name = deparse(expr), levelnames=levels(x),
                       spacing=3, space=1, suppressfirst=TRUE,
                       nopagebreak = "\\nopagebreak ",
-                      texify = TRUE, expr = substitute(x), override = TRUE ) {
+                      texify = getOption("tables.texify", FALSE), expr = substitute(x), override = TRUE ) {
     force(name)
     force(expr)
     x <- as.factor(x)
